%%
%% This is file `il2enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% cslatex.dtx  (with options: `il2enc')
%% 
%% Tento soubor je soucasti baliku CsLaTeX a je vygenerovan z
%% distribucniho souboru cslatex.dtx.
%% 
%% Copyright (c) 1994--98, 2002
%% Jaroslav Snajdr, Zdenek Wagner, Jiri Zlatuska a The LaTeX3 Project
%% 
%% Tento soubor NENI soucasti systemu LaTeX2e
%% ------------------------------------------
%% 
%% Dalsi informace naleznete na www.cstug.cz/cslatex.
%% 
\ProvidesFile{il2enc.def}[1997/08/20 CSLaTeX]
\DeclareFontEncoding{IL2}{\uccode152=152 \lccode152=184
                          \uccode184=152 \lccode184=184
                          \uccode165=165 \lccode165=181
                          \uccode181=165 \lccode181=181
                          \uccode169=169 \lccode169=185
                          \uccode185=169 \lccode185=185
                          \uccode171=171 \lccode171=187
                          \uccode187=171 \lccode187=187
                          \uccode174=174 \lccode174=190
                          \uccode190=174 \lccode190=190
                          \sfcode254=0   \lccode254=0
                          \sfcode255=0   \lccode255=0
                          \sfcode158=0   \lccode158=0
                          \sfcode159=0   \lccode159=0 }{}
\DeclareTextAccent{\"}{IL2}{127}
\DeclareTextAccent{\'}{IL2}{19}
\DeclareTextAccent{\.}{IL2}{95}
\DeclareTextAccent{\=}{IL2}{22}
\DeclareTextAccent{\^}{IL2}{94}
\DeclareTextAccent{\`}{IL2}{18}
\DeclareTextAccent{\~}{IL2}{126}
\DeclareTextAccent{\H}{IL2}{125}
\DeclareTextAccent{\u}{IL2}{21}
\DeclareTextAccent{\v}{IL2}{20}
\DeclareTextAccent{\r}{IL2}{23}
\DeclareTextCommand{\b}{IL2}[1]
   {\oalign{\null#1\crcr\hidewidth\sh@ft{29}%
    \vbox to.2ex{\hbox{\char22}\vss}\hidewidth}}
\DeclareTextCommand{\c}{IL2}[1]
   {\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent24 #1%
    \else{\ooalign{\unhbox\z@\crcr\hidewidth\char24\hidewidth}}\fi}
\DeclareTextCommand{\d}{IL2}[1]
   {\oalign{\null#1\crcr\hidewidth\sh@ft{08}.\hidewidth}}
\DeclareTextSymbol{\AE}{IL2}{29}
\DeclareTextSymbol{\OE}{IL2}{30}
\DeclareTextSymbol{\O}{IL2}{31}
\DeclareTextSymbol{\ae}{IL2}{26}
\DeclareTextSymbol{\i}{IL2}{16}
\DeclareTextSymbol{\j}{IL2}{17}
\DeclareTextSymbol{\oe}{IL2}{27}
\DeclareTextSymbol{\o}{IL2}{28}
\DeclareTextSymbol{\ss}{IL2}{25}
\DeclareTextSymbol{\textemdash}{IL2}{124}
\DeclareTextSymbol{\textendash}{IL2}{123}
\DeclareTextSymbol{\textexclamdown}{IL2}{60}
\DeclareTextSymbol{\textquestiondown}{IL2}{62}
\DeclareTextSymbol{\textquotedblleft}{IL2}{92}
\DeclareTextSymbol{\textquotedblright}{IL2}{`\"}
\DeclareTextSymbol{\textquoteleft}{IL2}{`\`}
\DeclareTextSymbol{\textquoteright}{IL2}{`\'}
\DeclareTextCommand{\L}{IL2}
   {\leavevmode\setbox0\hbox{L}\hbox to\wd0{\hss\char32L}}
\DeclareTextCommand{\l}{IL2}{{\char32l}}
\DeclareTextCompositeCommand{\r}{IL2}{A}
   {\leavevmode\setbox0\hbox{h}\dimen@\ht0\advance\dimen@-1ex%
    \rlap{\raise.67\dimen@\hbox{\char'27}}A}
\DeclareTextCommand{\SS}{IL2}{SS}
\DeclareTextCommand{\textdollar}{IL2}{{%
    \ifdim \fontdimen\@ne\font >\z@
      \slshape
    \else
      \upshape
    \fi
    \char`\$}}
\DeclareTextCommand{\textsterling}{IL2}{{%
    \ifdim \fontdimen\@ne\font >\z@
      \itshape
    \else
      \fontshape{ui}\selectfont
    \fi
    \char`\$}}
\DeclareTextComposite{\'}{IL2}{l}{'345}%
\DeclareTextComposite{\'}{IL2}{r}{'340}%
\DeclareTextComposite{\'}{IL2}{a}{'341}%
\DeclareTextComposite{\'}{IL2}{e}{'351}%
\DeclareTextComposite{\'}{IL2}{\i}{'355}%
\DeclareTextComposite{\'}{IL2}{i}{'355}%
\DeclareTextComposite{\'}{IL2}{o}{'363}%
\DeclareTextComposite{\'}{IL2}{u}{'372}%
\DeclareTextComposite{\'}{IL2}{y}{'375}%
\DeclareTextComposite{\'}{IL2}{L}{'305}%
\DeclareTextComposite{\'}{IL2}{R}{'300}%
\DeclareTextComposite{\'}{IL2}{A}{'301}%
\DeclareTextComposite{\'}{IL2}{E}{'311}%
\DeclareTextComposite{\'}{IL2}{I}{'315}%
\DeclareTextComposite{\'}{IL2}{O}{'323}%
\DeclareTextComposite{\'}{IL2}{U}{'332}%
\DeclareTextComposite{\'}{IL2}{Y}{'335}%
\DeclareTextComposite{\`}{IL2}{a}{'270}%
\DeclareTextComposite{\`}{IL2}{A}{'230}%
\DeclareTextComposite{\v}{IL2}{c}{'350}%
\DeclareTextComposite{\v}{IL2}{d}{'357}%
\DeclareTextComposite{\v}{IL2}{e}{'354}%
\DeclareTextComposite{\v}{IL2}{n}{'362}%
\DeclareTextComposite{\v}{IL2}{r}{'370}%
\DeclareTextComposite{\v}{IL2}{s}{'271}%
\DeclareTextComposite{\v}{IL2}{z}{'276}%
\DeclareTextComposite{\v}{IL2}{t}{'273}%
\DeclareTextComposite{\v}{IL2}{l}{'265}%
\DeclareTextComposite{\v}{IL2}{u}{'371}%
\DeclareTextComposite{\v}{IL2}{C}{'310}%
\DeclareTextComposite{\v}{IL2}{D}{'317}%
\DeclareTextComposite{\v}{IL2}{E}{'314}%
\DeclareTextComposite{\v}{IL2}{N}{'322}%
\DeclareTextComposite{\v}{IL2}{R}{'330}%
\DeclareTextComposite{\v}{IL2}{S}{'251}%
\DeclareTextComposite{\v}{IL2}{T}{'253}%
\DeclareTextComposite{\v}{IL2}{Z}{'256}%
\DeclareTextComposite{\v}{IL2}{L}{'245}%
\DeclareTextComposite{\v}{IL2}{U}{'331}%
\DeclareTextComposite{\^}{IL2}{o}{'364}%
\DeclareTextComposite{\^}{IL2}{O}{'324}%
\DeclareTextComposite{\"}{IL2}{a}{'344}%
\DeclareTextComposite{\"}{IL2}{o}{'366}%
\DeclareTextComposite{\"}{IL2}{u}{'374}%
\DeclareTextComposite{\"}{IL2}{A}{'304}%
\DeclareTextComposite{\"}{IL2}{O}{'326}%
\DeclareTextComposite{\"}{IL2}{U}{'334}%
\DeclareTextComposite{\r}{IL2}{u}{'371}%
\DeclareTextComposite{\r}{IL2}{U}{'331}%
\DeclareTextSymbol{\flqq}{IL2}{158}%
\DeclareTextSymbol{\frqq}{IL2}{159}%
\DeclareTextSymbol{\clqq}{IL2}{254}%
\DeclareTextCommand{\crqq}{IL2}%
  {{\edef\@SF{\spacefactor\the\spacefactor}\char255 \@SF\relax}}%
\ifx\addlanguage\undefined\else
  \ifx\LdfInit\@undefined
    \def\LdfInit{%
      \chardef\atcatcode=\catcode`\@
      \catcode`\@=11\relax
      \input babel.def\relax
      \catcode`\@=\atcatcode \let\atcatcode\relax
      \LdfInit}
  \fi
\endinput\fi
\endinput
%%
%% End of file `il2enc.def'.
